@@ -1,11 +1,10 @@
 import os
 import json
-import time
 from typing import List
 
 from uhashring import HashRing
 
-from fastapi_crawler_scheduler.dbRedisHelper import redis_db
+from fastapi_crawler_scheduler.dbRedisHelper import redis_db, standard_time
 from config import settings
 from utils.spiderSchedular import scheduler
 from utils.crawlerScheduler import crawl_sitemap, crawl_twitter, crawl_latest_news
@@ -188,7 +187,7 @@ class NewsScheduler(object):
                     if scheduler.get_job(job_id=apscheduler_id):
                         scheduler.remove_job(job_id=apscheduler_id)
                     redis_db.delete_key(lock_name=delete_key)
-                    redis_db.delete_key(lock_name=f"scheduler_job:{apscheduler_id}")
+                    redis_db.delete_key(lock_name=f"scheduler_job:{os.getpid()}:{apscheduler_id}")
                 else:
                     self.process_check_count(process_id=process_id, check_key=delete_key)
 
@@ -223,19 +222,17 @@ class NewsScheduler(object):
     def sync_scheduler_job_to_redis(self) -> None:
         job_list = scheduler.get_jobs()
         for job in job_list:
-            key = f"scheduler_job:{job.id}"
-            redis_db.process_acquire(lock_name=key, expire_time=300)
+            key = f"scheduler_job:{os.getpid()}:{job.id}"
+            lock_value = standard_time()
+            redis_db.process_acquire(lock_name=key, lock_value=lock_value, expire_time=300)
 
     def run(self) -> None:
-        start_time = time.time()
         self.check_backend_task()
         self.check_all_task()
         self.check_insert_task()
         self.check_update_task()
         self.check_delete_task()
         self.sync_scheduler_job_to_redis()
-        end_time = time.time()
-        print(f"总耗时：{end_time - start_time} seconds")
 
 
 news_scheduler = NewsScheduler()
